<?php
/**
 * Plugin Name: Cryptonix for WooCommerce
 * Description: A payment method for WooCommerce that allows your users to pay in cryptocurrency.
 * Version: 1.0
 * Author: Cryptonix
 * Author URI: https://cryptonix.com
 * Requires at least: 6.3
 * Requires PHP: 8.0
 * Text Domain: cryptonix-for-woocommerce
 * Requires Plugins: woocommerce
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

if (!defined('ABSPATH')) {
    exit;
}

define('CRYPTONIX_PAYMENT_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('CRYPTONIX_PAYMENT_PLUGIN_VERSION', 1.0);

require_once __DIR__ . '/vendor/autoload.php';

final class WC_Cryptonix_Payment {
    private static ?self $instance = null;

    private function __construct() {
        $this->init();
    }

    public static function i(): self {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    public function init(): void {
        add_filter('woocommerce_payment_gateways', [$this, 'add_payment_methods']);
        add_action('woocommerce_blocks_loaded', [$this, 'add_blocks_payment_methods']);
    }

    public function add_payment_methods(array $methods): array {
        $methods[] = Cryptonix_Payment\Woocommerce\Gateway\Cryptonix_Gateway::class;

        return $methods;
    }

    public function add_blocks_payment_methods(): void {
        add_action('woocommerce_blocks_payment_method_type_registration', function ($payment_method_registry) {
            $payment_method_registry->register(new Cryptonix_Payment\Woocommerce\Gateway\Cryptonix_Block_Gateway());
        });
    }

    public static function asset_url(string $path): string {
        return plugins_url( 'assets/' . $path, __FILE__ );
    }
}

WC_Cryptonix_Payment::i();
