<?php

declare(strict_types=1);

namespace Cryptonix_Payment\DTO;

class Create_Order_DTO {
    private string $order_id;
    private string $currency;
    private float $amount;
    private ?string $order_description = null;
    private array $allowed_currencies = [];
    private string $success_url;
    private string $fail_url;
    private int $order_timeout = 3600;
    private int $invoice_timeout = 600;
    private string $client_id;
    private string $language = 'en';
    private array $customer_data = [];
    private ?string $cancel_url = null;

    public function __construct(
        string $order_id,
        string $currency,
        float $amount,
    ) {
        $this->order_id = $order_id;
        $this->currency = $currency;
        $this->amount = $amount;
    }

    public function set_order_description(?string $order_description): self {
        $this->order_description = $order_description;
        return $this;
    }

    public function set_allowed_currencies(array $allowed_currencies): self {
        $this->allowed_currencies = $allowed_currencies;
        return $this;
    }

    public function set_success_url(string $url): self {
        $this->success_url = $url;
        return $this;
    }

    public function set_fail_url(string $url): self {
        $this->fail_url = $url;
        return $this;
    }

    public function set_cancel_url(string $url): self {
        $this->cancel_url = $url;
        return $this;
    }

    public function set_client_id(string $client_id): self {
        $this->client_id = $client_id;
        return $this;
    }

    public function set_language(string $language): self {
        $this->language = $language;
        return $this;
    }

    public function set_customer_data( array $customer_data ): self {
        $this->customer_data = $customer_data;

        return $this;
    }

    public function to_array(): array {
        return [
            'timestamp' => time(),
            'external_order_id' => $this->order_id,
            'store_name' => get_bloginfo('name'),
            'store_url' => get_home_url(),
            'order_currency' => $this->currency,
            'order_amount' => $this->amount,
            'order_description' => $this->order_description,
            'allowed_currencies' => $this->allowed_currencies,
            'success_url' => $this->success_url,
            'fail_url' => $this->fail_url,
            'cancel_url' => $this->cancel_url,
            'order_timeout' => $this->order_timeout,
            'invoice_timeout' => $this->invoice_timeout,
            'client_id' => $this->client_id,
            'client_data' => $this->customer_data,
            'language' => $this->language,
        ];
    }
}
